@@ -1,5 +1,5 @@
 using Optimization, OrdinaryDiffEqTsit5, OptimizationOptimisers,
-      SciMLSensitivity, Lux, Random, ComponentArrays, MLUtils
+    SciMLSensitivity, Lux, Random, ComponentArrays, MLUtils
 using Test
 
 rng = Random.default_rng()
@@ -7,21 +7,21 @@ rng = Random.default_rng()
 function newtons_cooling(du, u, p, t)
     temp = u[1]
     k, temp_m = p
-    du[1] = dT = -k * (temp - temp_m)
+    return du[1] = dT = -k * (temp - temp_m)
 end
 
 function true_sol(du, u, p, t)
     true_p = [log(2) / 8.0, 100.0]
-    newtons_cooling(du, u, true_p, t)
+    return newtons_cooling(du, u, true_p, t)
 end
 
 function dudt_(u, p, t)
-    ann(u, p, st)[1] .* u
+    return ann(u, p, st)[1] .* u
 end
 
 function callback(state, l) #callback function to observe training
     display(l)
-    return l < 1e-2
+    return l < 1.0e-2
 end
 
 u0 = Float32[200.0]
@@ -39,13 +39,13 @@ pp = ComponentArray(pp)
 prob = ODEProblem{false}(dudt_, u0, tspan, pp)
 
 function predict_adjoint(fullp, time_batch)
-    Array(solve(prob, Tsit5(), p = fullp, saveat = time_batch))
+    return Array(solve(prob, Tsit5(), p = fullp, saveat = time_batch))
 end
 
 function loss_adjoint(fullp, p)
     (batch, time_batch) = p
     pred = predict_adjoint(fullp, time_batch)
-    sum(abs2, batch .- pred)
+    return sum(abs2, batch .- pred)
 end
 
 k = 10
@@ -54,37 +54,56 @@ train_loader = MLUtils.DataLoader((ode_data, t), batchsize = k)
 numEpochs = 300
 l1 = loss_adjoint(pp, (train_loader.data[1], train_loader.data[2]))[1]
 
-optfun = OptimizationFunction(loss_adjoint,
-    Optimization.AutoZygote())
+optfun = OptimizationFunction(
+    loss_adjoint,
+    Optimization.AutoZygote()
+)
 optprob = OptimizationProblem(optfun, pp, train_loader)
 
-optfun = OptimizationFunction(loss_adjoint,
-    Optimization.AutoForwardDiff())
+optfun = OptimizationFunction(
+    loss_adjoint,
+    Optimization.AutoForwardDiff()
+)
 optprob = OptimizationProblem(optfun, pp, train_loader)
 
-res1 = Optimization.solve(optprob, Optimisers.Adam(0.05),
-    callback = callback, maxiters = numEpochs)
+res1 = Optimization.solve(
+    optprob, Optimisers.Adam(0.05),
+    callback = callback, maxiters = numEpochs
+)
 @test 10res1.objective < l1
 
 optfun = OptimizationFunction(
-    (θ, p) -> loss_adjoint(θ, batch,
-        time_batch),
-    AutoSymbolics())
+    (θ, p) -> loss_adjoint(
+        θ, batch,
+        time_batch
+    ),
+    AutoSymbolics()
+)
 optprob = OptimizationProblem(optfun, pp)
 using IterTools: ncycle
-@test_broken res1 = Optimization.solve(optprob, Optimisers.Adam(0.05),
+@test_broken res1 = Optimization.solve(
+    optprob, Optimisers.Adam(0.05),
     ncycle(train_loader, numEpochs),
-    callback = callback, maxiters = numEpochs)
+    callback = callback, maxiters = numEpochs
+)
 # @test 10res1.objective < l1
 
 function loss_grad(res, fullp, p)
     (batch, time_batch) = p
     pred = solve(prob, Tsit5(), p = fullp, saveat = time_batch)
-    res .= Array(adjoint_sensitivities(pred, Tsit5(); t = time_batch, p = fullp,
-        dgdu_discrete = (out, u, p, t, i) -> (out .= -2 *
-                                                     (batch[i] .-
-                                                      u[1])),
-        sensealg = InterpolatingAdjoint())[2]')
+    return res .= Array(
+        adjoint_sensitivities(
+            pred, Tsit5(); t = time_batch, p = fullp,
+            dgdu_discrete = (out, u, p, t, i) -> (
+                out .= -2 *
+                    (
+                    batch[i] .-
+                        u[1]
+                )
+            ),
+            sensealg = InterpolatingAdjoint()
+        )[2]'
+    )
 end
 
 function callback(st, l, pred; doplot = false)
@@ -94,13 +113,17 @@ function callback(st, l, pred; doplot = false)
         scatter!(pl, t, pred[1, :], label = "prediction")
         display(plot(pl))
     end
-    return l < 1e-3
+    return l < 1.0e-3
 end
 
-optfun = OptimizationFunction(loss_adjoint,
-    grad = loss_grad)
+optfun = OptimizationFunction(
+    loss_adjoint,
+    grad = loss_grad
+)
 optprob = OptimizationProblem(optfun, pp, train_loader)
 
-res1 = Optimization.solve(optprob, Optimisers.Adam(0.05),
-    callback = callback, maxiters = numEpochs)
+res1 = Optimization.solve(
+    optprob, Optimisers.Adam(0.05),
+    callback = callback, maxiters = numEpochs
+)
 @test 10res1.objective < l1
